=======
History
=======

1.0.2 (2016-05-24)
------------------

* Fixed the PyPI badge in the documentation
* Added some examples both in documentation and in the test suite

1.0.1 (2016-05-21)
------------------

* Last minute change of package name on PyPI due to a name clash.

1.0.0 (2016-05-19)
------------------

* First release on PyPI.
